==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/NativeUISlider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUISlider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUISlider, _super);
    function NativeUISlider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ap = null;
        _this.aq = null;
        return _this;
    }
    NativeUISlider.prototype.get_c = function () {
        return 5;
    };
    Object.defineProperty(NativeUISlider.prototype, "aw", {
        get: function () {
            var a = this.o(2);
            return a;
        },
        set: function (a) {
            this.ad(2, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "au", {
        get: function () {
            var a = this.o(10);
            return a;
        },
        set: function (a) {
            this.ad(10, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "at", {
        get: function () {
            var a = this.o(11);
            return a;
        },
        set: function (a) {
            this.ad(11, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "av", {
        get: function () {
            var a = this.o(12);
            return a;
        },
        set: function (a) {
            this.ad(12, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "ar", {
        get: function () {
            return this.ap;
        },
        set: function (a) {
            var b = this.ap;
            this.ap = a;
            if (this.ap != null) {
                this.w(4, this.ap);
            }
            else {
                this.ab(4, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "as", {
        get: function () {
            return this.aq;
        },
        set: function (a) {
            var b = this.aq;
            this.aq = a;
            if (this.aq != null) {
                this.w(0, this.aq);
            }
            else {
                this.ab(0, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUISlider.$t = markType(NativeUISlider, 'NativeUISlider', NativeUIComponent.$);
    return NativeUISlider;
}(NativeUIComponent));
export { NativeUISlider };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/NativeUISlider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUISlider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUISlider, _super);
    function NativeUISlider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.at = null;
        _this.au = null;
        return _this;
    }
    NativeUISlider.prototype.get_c = function () {
        return 5;
    };
    Object.defineProperty(NativeUISlider.prototype, "a0", {
        get: function () {
            var a = this.o(2);
            return a;
        },
        set: function (a) {
            this.af(2, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "ay", {
        get: function () {
            var a = this.o(10);
            return a;
        },
        set: function (a) {
            this.af(10, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "ax", {
        get: function () {
            var a = this.o(11);
            return a;
        },
        set: function (a) {
            this.af(11, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "az", {
        get: function () {
            var a = this.o(12);
            return a;
        },
        set: function (a) {
            this.af(12, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "av", {
        get: function () {
            return this.at;
        },
        set: function (a) {
            var b = this.at;
            this.at = a;
            if (this.at != null) {
                this.x(4, this.at);
            }
            else {
                this.ad(4, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "aw", {
        get: function () {
            return this.au;
        },
        set: function (a) {
            var b = this.au;
            this.au = a;
            if (this.au != null) {
                this.x(0, this.au);
            }
            else {
                this.ad(0, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUISlider.$t = markType(NativeUISlider, 'NativeUISlider', NativeUIComponent.$);
    return NativeUISlider;
}(NativeUIComponent));
export { NativeUISlider };
